/*
  mainwindow.cpp
  Copyright (C) 2010 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of radiko-player.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

//#define DEBUG

#include "mainwindow.h"

#include <qwidget.h>
#include <stdio.h>
#include "version.h"
#include "process.h"

#include <qdialog.h>
#include <qvbox.h>
#include <qlayout.h>
#include <qcombobox.h>
#include <qpushbutton.h>

#ifndef QWS
#include <qlabel.h>
#endif
#ifdef QWS
#include <qcopchannel_qws.h>
#endif

#define QCOPNAME "QPE/Application/radiko"

MainWindow::MainWindow( QWidget *parent, const char *name, WFlags fl) :
	QWidget(parent, name, fl)
{
//	conf = new QGConf(this, "config");

#ifndef QWS
	resize(640,640);
#endif
	setCaption(QString::fromUtf8("radiko player - ") + RADIKO_VER);

	QVBoxLayout *vbox = new QVBoxLayout(this);

	QHBox *hbox = new QHBox(this);
	QWidget *l_dummy = new QWidget(hbox);
	hbox->setStretchFactor(l_dummy, 100);
	channel = new QComboBox(hbox);
	button = new QPushButton("Play", hbox);
	button->setToggleButton(true);
	QWidget *r_dummy = new QWidget(hbox);
	hbox->setStretchFactor(r_dummy, 100);
	vbox->addWidget(hbox);

	connect(button, SIGNAL(clicked()),
			this, SLOT(toggle_playbutton()));
//	connect(&proc, SIGNAL(started()),
//			this, SLOT(process_start()));
//	connect(&proc, SIGNAL(exited(int)),
//			this, SLOT(process_stop(int)));

#if 0
#ifdef QWS
	QCopChannel *qcop = new QCopChannel(QCOPNAME, this);
	connect(qcop, SIGNAL(received(const QCString &, const QByteArray&)),
			this, SLOT(recvQCop(const QCString &, const QByteArray&)));
#endif
#endif
//	conf->migrate();

	updateChannelList();
}

MainWindow::~MainWindow()
{
}

void MainWindow::updateChannelList()
{
	channel->clear();
	channel->insertItem(QString::fromUtf8("TBS - TBSラジオ"));
    channel->insertItem(QString::fromUtf8("QRR - 文化放送"));
    channel->insertItem(QString::fromUtf8("LFR - ニッポン放送"));
    channel->insertItem(QString::fromUtf8("NSB - ラジオNIKKEI"));
    channel->insertItem(QString::fromUtf8("INT - INTER FM"));
    channel->insertItem(QString::fromUtf8("FMT -TOKYO FM"));
    channel->insertItem(QString::fromUtf8("FMJ - J-WAVE"));

    channel->insertItem(QString::fromUtf8("ABC - ABC ラジオ"));
    channel->insertItem(QString::fromUtf8("MBS - MBS ラジオ"));
    channel->insertItem(QString::fromUtf8("OBC - ラジオ大阪"));
    channel->insertItem(QString::fromUtf8("CCL - FM COCOLO"));
    channel->insertItem(QString::fromUtf8("802 - FM80.2"));
    channel->insertItem(QString::fromUtf8("FMO - FM OSAKA"));
}

QString MainWindow::getCommand()
{
	QString cmd;
	QString ch = channel->currentText().left(3);
	cmd =
#ifdef QWS
		"/opt/QtPalmtop/share/radiko/"
#endif
		"./rtmpdump "
		"-q "
		"--rtmp \"rtmpe://radiko.smartstream.ne.jp:1935\" "
		"--playpath \"simul-stream\" "
		"--swfUrl \"http://radiko-dl.ssdl1.smartstream.ne.jp/radiko-dl/1.1/player/player_0.1.2.swf\" "
		"--pageUrl \"http://radiko.jp/player/player.html#" + ch + "\" "
		"--app \"" + ch + "/_defInst_\" "
		"--flashVer \"LNX 10,1,53,64\" "
		"--live"
		" | "
#ifdef QWS
		"/opt/QtPalmtop/share/radiko/"
#endif
		"./mplayer - > /dev/null 2>&1";

//	printf("cmd:%s\n", cmd.latin1());
	return cmd;
}

void MainWindow::toggle_playbutton()
{
	bool on = button->isOn();
//	printf("button:%d\n", on);

	if (on) {
//		button->setOn(false);
		proc.setCommand(getCommand());
		proc.start();
		button->setText("Stop");
	} else {
//		button->setOn(true);
		proc.stop();
		button->setText("Play");
	}
}

void MainWindow::process_start()
{
//	printf("%s\n", __PRETTY_FUNCTION__);
//	button->setOn(true);
	button->setText("Stop");
}

void MainWindow::process_stop(int status)
{
//	printf("%s\n", __PRETTY_FUNCTION__);
//	button->setOn(false);
	button->setText("Play");
}
