/*
  qgconf.cpp
  Copyright (C) 2010 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of radiko.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

//#define DEBUG

#include "qgconf.h"
#include <qobject.h>
#include <qstring.h>
#include <qregexp.h>

QGConf::QGConf(QObject *parent, const char *name)
	: QObject(parent, name)
#ifdef QWS
	, Config("radiko")
#endif
{
	setGroup("");
	prefix = "";
}

void QGConf::writeEntry ( const QString & key, const char * value )
{
	QString str(value);

	CONFIGCLASS::writeEntry( key, value );
	if(group_name == "")
		emit configChanged( key, str );
}

void QGConf::writeEntry ( const QString & key, const QString & value )
{
	CONFIGCLASS::writeEntry( key, value );
	if(group_name == "")
		emit configChanged( key, value );
}

void QGConf::writeEntry ( const QString & key, int num )
{
	QString str;
	str.setNum(num);
	CONFIGCLASS::writeEntry( key, num );
	if(group_name == "")
		emit configChanged( key, str );
}

void QGConf::reloadEntry ( const QString & key, const QString defl )
{
	if(group_name == "")
		emit configChanged( key, readEntry(key, defl) );
}

void QGConf::reloadNumEntry ( const QString & key, int defl )
{
	QString str;
	str.setNum( readNumEntry(key, defl) );
	if(group_name == "")
		emit configChanged( key, str );
}

void QGConf::migrate()
{
}

void QGConf::setGroup(const QString &group)
{
#ifdef QWS
	if(group == "")
		CONFIGCLASS::setGroup("General");
	else
		CONFIGCLASS::setGroup(group);
#else
	if(group != group_name) {
		endGroup();
		beginGroup("/radiko/" + group);
	}
#endif
	group_name = group;
}

QString QGConf::group()
{
	return group_name;
}
